Struct EvmLlvmBackend
pub struct EvmLlvmBackend {Show 23 fields
pub(crate) cx: &'static Context,
pub(crate) _dh: DiagnosticHandlerGuard,
pub(crate) bcx: Builder<'static>,
pub(crate) module: Module<'static>,
pub(crate) machine: TargetMachine,
pub(crate) orc: Option<OrcJitState>,
pub(crate) _tscx: Option<ThreadSafeContext>,
pub(crate) _cx_handle: Option<Box<ManuallyDrop<Context>>>,
pub(crate) _aot_cx: Option<Box<Context>>,
pub(crate) di_state: Option<DiState>,
pub(crate) ty_void: VoidType<'static>,
pub(crate) ty_ptr: PointerType<'static>,
pub(crate) ty_i1: IntType<'static>,
pub(crate) ty_i8: IntType<'static>,
pub(crate) ty_i32: IntType<'static>,
pub(crate) ty_i64: IntType<'static>,
pub(crate) ty_i256: IntType<'static>,
pub(crate) ty_isize: IntType<'static>,
pub(crate) aot: bool,
pub(crate) backend_config: BackendConfig,
pub(crate) scratch: String,
pub(crate) function_counter: u32,
pub(crate) function_names: HashMap<u32, String, FxBuildHasher>,
}llvm only.Expand description
The LLVM-based EVM bytecode compiler backend.
Fields
cx: &'static Context_dh: DiagnosticHandlerGuardbcx: Builder<'static>module: Module<'static>machine: TargetMachineorc: Option<OrcJitState>_tscx: Option<ThreadSafeContext>_cx_handle: Option<Box<ManuallyDrop<Context>>>_aot_cx: Option<Box<Context>>di_state: Option<DiState>ty_void: VoidType<'static>ty_ptr: PointerType<'static>ty_i1: IntType<'static>ty_i8: IntType<'static>ty_i32: IntType<'static>ty_i64: IntType<'static>ty_i256: IntType<'static>ty_isize: IntType<'static>aot: boolbackend_config: BackendConfigscratch: Stringfunction_counter: u32function_names: HashMap<u32, String, FxBuildHasher>Implementations
impl EvmLlvmBackend
impl EvmLlvmBackend
pub fn new(aot: bool) -> Result<EvmLlvmBackend, Report>
pub fn new(aot: bool) -> Result<EvmLlvmBackend, Report>
Creates a new LLVM backend for the host machine.
pub fn take_last_resource_tracker(&mut self) -> Option<ResourceTracker>
pub fn take_last_resource_tracker(&mut self) -> Option<ResourceTracker>
Pops and returns the ResourceTracker for the last committed
JIT module.
Each call to jit_function commits a module
with its own tracker. The caller takes ownership and is responsible for calling
tracker.remove() to free the machine code when it is no longer needed.
The caller must also hold a JitDylibGuard to prevent the owning JITDylib from
being recycled before the tracker is removed.
Returns None in AOT mode or if no modules have been committed.
pub fn jit_dylib_guard(&self) -> Arc<JitDylibGuard>
pub fn jit_dylib_guard(&self) -> Arc<JitDylibGuard>
Returns a shared handle that keeps this backend’s JITDylib alive.
The JITDylib will not be cleared or recycled until all JitDylibGuard handles
(and the backend itself) are dropped. Callers holding JIT function pointers must
retain a guard to prevent the backing code from being freed.